//[mahjong-utils](../../../index.md)/[mahjongutils.hora](../index.md)/[KokushiHoraHandPattern](index.md)/[KokushiHoraHandPattern](-kokushi-hora-hand-pattern.md)

# KokushiHoraHandPattern

[common]\
constructor(repeated: [Tile](../../mahjongutils.models/-tile/index.md), agari: [Tile](../../mahjongutils.models/-tile/index.md), tsumo: [Boolean](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-boolean/index.html), selfWind: [Wind](../../mahjongutils.models/-wind/index.md)? = null, roundWind: [Wind](../../mahjongutils.models/-wind/index.md)? = null)
